summaryrefslogtreecommitdiffstats
path: root/Modules
diff options
context:
space:
mode:
authorBrad King <brad.king@kitware.com>2018-06-18 17:55:52 (GMT)
committerBrad King <brad.king@kitware.com>2018-06-18 17:58:21 (GMT)
commit1e356734a78b821525560aa1d6d5557f74f2646d (patch)
treedde2d383a65ffd1481d8e271b5dff54ce57392ec /Modules
parentef5e2e8a62982ebccf4883fc7a01cdb66f8ca183 (diff)
downloadCMake-1e356734a78b821525560aa1d6d5557f74f2646d.zip
CMake-1e356734a78b821525560aa1d6d5557f74f2646d.tar.gz
CMake-1e356734a78b821525560aa1d6d5557f74f2646d.tar.bz2
FindCURL: Rename imported target to match upstream CURL
Upstream CURL provides imported target `CURL::libcurl`. Rename the target added by `FindCURL` to match. We don't need compatibility with the old name because it has never been in a CMake release (except a 3.12 release candidate). Suggested-by: Jakub Zakrzewski <slither.jz@gmail.com> Acked-by: Rolf Eike Beer <eike@sf-mail.de> Fixes: #18091
Diffstat (limited to 'Modules')
-rw-r--r--Modules/FindCURL.cmake10
1 files changed, 5 insertions, 5 deletions
diff --git a/Modules/FindCURL.cmake b/Modules/FindCURL.cmake
index e66ae92..a549765 100644
--- a/Modules/FindCURL.cmake
+++ b/Modules/FindCURL.cmake
@@ -10,7 +10,7 @@
# IMPORTED Targets
# ^^^^^^^^^^^^^^^^
#
# This module defines :prop_tgt:`IMPORTED` target ``CURL::CURL``, if
# curl has been found.
#
# Result Variables
@@ -67,9 +67,9 @@ if(CURL_FOUND)
set(CURL_LIBRARIES ${CURL_LIBRARY})
set(CURL_INCLUDE_DIRS ${CURL_INCLUDE_DIR})
- if(NOT TARGET CURL::CURL)
- add_library(CURL::CURL UNKNOWN IMPORTED)
- set_target_properties(CURL::CURL PROPERTIES INTERFACE_INCLUDE_DIRECTORIES "${CURL_INCLUDE_DIRS}")
- set_property(TARGET CURL::CURL APPEND PROPERTY IMPORTED_LOCATION "${CURL_LIBRARY}")
+ if(NOT TARGET CURL::libcurl)
+ add_library(CURL::libcurl UNKNOWN IMPORTED)
+ set_target_properties(CURL::libcurl PROPERTIES INTERFACE_INCLUDE_DIRECTORIES "${CURL_INCLUDE_DIRS}")
+ set_property(TARGET CURL::libcurl APPEND PROPERTY IMPORTED_LOCATION "${CURL_LIBRARY}")
endif()
endif()
@@ -10,7 +10,7 @@
# ^^^^^^^^^^^^^^^^
#
-# This module defines :prop_tgt:`IMPORTED` target ``CURL::CURL``, if
+# This module defines :prop_tgt:`IMPORTED` target ``CURL::libcurl``, if
# curl has been found.
#